<?php
/*
 * Settings and administration
 * @since 1.0
 */

add_action('admin_menu', 'dmst_portfolio_add_page');
add_action('admin_init', 'dmst_portfolio_admin_init');

/**
 * Add admin page
 * @since 1.0 
 */
function dmst_portfolio_add_page() {
    add_options_page(__('DMS3-Portfolio', DMST_PORTFOLIO_TEXT_DOMAIN), __('DeMomentSomTres Portfolio', DMST_PORTFOLIO_TEXT_DOMAIN), 'manage_options', 'dmst_portfolio', 'dmst_portfolio_option_page');
}

/**
 * Admin page contents
 * @since 1.0
 */
function dmst_portfolio_option_page() {
    ?>
    <div class="wrap" style="float:left;width:50%;">
        <?php screen_icon(); ?>
        <h2><?php _e('DeMomentSomTres - Portfolio', DMST_PORTFOLIO_TEXT_DOMAIN); ?></h2>
        <form action="options.php" method="post">
            <?php settings_fields('dmst_portfolio_options'); ?>
            <?php do_settings_sections('dmst_portfolio'); ?>
            <input name="Submit" class="button button-primary" type="submit" value="<?php _e('Save Changes', DMST_PORTFOLIO_TEXT_DOMAIN); ?>"/>
        </form>
    </div>
    <?php
    echo '<div style="background-color:#eee; width:45%;float:right;padding:10px;">';
    echo '<h3>' . __('Options', DMST_PORTFOLIO_TEXT_DOMAIN) . '</h3>' . '<pre style="font-size:0.8em;">';
    print_r(get_option(DMST_PORTFOLIO_OPTIONS));
    echo '</pre>';
    echo '</div>';
}

/**
 * Admin page options
 * @since 1.0
 */
function dmst_portfolio_admin_init() {
    register_setting('dmst_portfolio_options', 'dmst_portfolio_options', 'dmst_portfolio_validate_options');
    add_settings_section('dmst_portfolio_services', __('Services', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portfolio_section_services', 'dmst_portfolio');
    add_settings_section('dmst_portfolio_works', __('Works', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portfolio_section_works', 'dmst_portfolio');
    add_settings_section('dmst_portfolio_slugs', __('Slugs', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portfolio_section_slugs', 'dmst_portfolio');
    //add_settings_section('dmst_portfolio_advanced', __('Advanced', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portfolio_section_advanced', 'dmst_portfolio');

    add_settings_field('dmst_portfolio_service_label', __('Label for service (single)', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portfolio_field_label_service', 'dmst_portfolio', 'dmst_portfolio_services');
    add_settings_field('dmst_portfolio_services_label', __('Label for services (multiple)', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portfolio_field_label_services', 'dmst_portfolio', 'dmst_portfolio_services');
    add_settings_field('dmst_portfolio_services_page', __('Page that shows all services', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portfolio_field_page_services', 'dmst_portfolio', 'dmst_portfolio_services');
    add_settings_field('dmst_portfolio_services_redirect', __('Javascript redirect if user accesses directly a service', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portfolio_field_redirect_services', 'dmst_portfolio', 'dmst_portfolio_services');
//    add_settings_field('dmst_portfolio_services_social', __('Show social share buttons linked to services (requires simple share button adder plugin)', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portfolio_field_social_services', 'dmst_portfolio', 'dmst_portfolio_services');
    add_settings_field('dmst_portfolio_services_offer', __('Special offer text', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portfolio_field_offer_services', 'dmst_portfolio', 'dmst_portfolio_services');
    add_settings_field('dmst_portfolio_services_offer_detail', __('Special offer text to see in the detail view', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portfolio_field_offer_detail_services', 'dmst_portfolio', 'dmst_portfolio_services');
    add_settings_field('dmst_portfolio_services_imagesize', __('Service featured image size in shortcode', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portolio_field_imagesize_service', 'dmst_portfolio', 'dmst_portfolio_services');
    add_settings_field('dmst_portfolio_services_classes', __('Classes to add to Services\'div', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portolio_field_classes_services', 'dmst_portfolio', 'dmst_portfolio_services');
    add_settings_field('dmst_portfolio_works_classes', __('Classes to add to Service\'s Works\'div', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portolio_field_classes_works', 'dmst_portfolio', 'dmst_portfolio_services');
    add_settings_field('dmst_portfolio_works_byrow', __('Number of works to show in every row in Service\'s Works Gallery', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portolio_field_byrow_services', 'dmst_portfolio', 'dmst_portfolio_services');

    add_settings_field('dmst_portfolio_work_label', __('Label for work (single)', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portfolio_field_label_work', 'dmst_portfolio', 'dmst_portfolio_works');
    add_settings_field('dmst_portfolio_works_label', __('Label for work (multiple)', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portfolio_field_label_works', 'dmst_portfolio', 'dmst_portfolio_works');
    add_settings_field('dmst_portfolio_works_page', __('Page that shows the works portfolio', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portfolio_field_page_works', 'dmst_portfolio', 'dmst_portfolio_works');
    add_settings_field('dmst_portfolio_works_redirect', __('Javascript redirect if user accesses directly a work', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portfolio_field_redirect_works', 'dmst_portfolio', 'dmst_portfolio_works');
//    add_settings_field('dmst_portfolio_works_social', __('Show social share buttons linked to works (requires simple share button adder plugin)', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portfolio_field_social_works', 'dmst_portfolio', 'dmst_portfolio_works');
    add_settings_field('dmst_portfolio_works_imagesize', __('Work featured image size in shortcode', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portolio_field_imagesize_work', 'dmst_portfolio', 'dmst_portfolio_works');

    add_settings_field('dmst_portfolio_services_slug', __('Slug for services', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portfolio_field_slug_service', 'dmst_portfolio', 'dmst_portfolio_slugs');
    add_settings_field('dmst_portfolio_works_slug', __('Slug for works', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portfolio_field_slug_work', 'dmst_portfolio', 'dmst_portfolio_slugs');

    //add_settings_field('dmst_portfolio_bootstrap', __('I don\'t want bootstrap scripts to be enqueued by this plugin because another plugin or the theme has already included them', DMST_PORTFOLIO_TEXT_DOMAIN), 'dmst_portfolio_field_bootstrap', 'dmst_portfolio', 'dmst_portfolio_advanced');
}

/**
 * Portfolio options validation
 * @param mixed $input
 * @return mixed
 * @since 1.0
 */
function dmst_portfolio_validate_options($input) {
    if ('' == $input['slug_service']):
        $input['slug_service'] = __('portfolio-service', DMST_PORTFOLIO_TEXT_DOMAIN);
    endif;
    if ('' == $input['slug_work']):
        $input['slug_work'] = __('portfolio-work', DMST_PORTFOLIO_TEXT_DOMAIN);
    endif;
    if ('0' == $input['page_services']):
        unset($input['page_services']);
    endif;
    if ('0' == $input['page_works']):
        unset($input['page_works']);
    endif;
    if (($input['slug_service'] != dmst_portfolio_get_slug_service()) || ($input['slug_work'] != dmst_portfolio_get_slug_work())):
        add_settings_error(
                '', '', __('Attention: after changing slugs you should save Permalink options again', DMST_PORTFOLIO_TEXT_DOMAIN) . ' <a href="options-permalink.php" target="_blank">' . __('here', DMST_PORTFOLIO_TEXT_DOMAIN) . '</a></strong></p>', 'error'
        );
    endif;
    $input = array_map('dmst_portfolio_esc_attr', $input);
    return $input;
}

/**
 * Create the field: label_work
 * @since 1.0
 */
function dmst_portfolio_field_label_work() {
    $value = dmst_portfolio_get_label_work();
    dmst_portfolio_input('label_work', $value);
}

/**
 * Create the field: label_works
 * @since 1.0
 */
function dmst_portfolio_field_label_works() {
    $value = dmst_portfolio_get_label_works();
    dmst_portfolio_input('label_works', $value);
}

/**
 * Create the field: label_service
 * @since 1.0
 */
function dmst_portfolio_field_label_service() {
    $value = dmst_portfolio_get_label_service();
    dmst_portfolio_input('label_service', $value);
}

/**
 * Create the field: label_services
 * @since 1.0
 */
function dmst_portfolio_field_label_services() {
    $value = dmst_portfolio_get_label_services();
    dmst_portfolio_input('label_services', $value);
}

/**
 * Create the field: slug_service
 * @since 1.0
 */
function dmst_portfolio_field_slug_service() {
    $value = dmst_portfolio_get_slug_service();
    dmst_portfolio_input('slug_service', $value);
}

/**
 * Create the field: slug_work
 * @since 1.0
 */
function dmst_portfolio_field_slug_work() {
    $value = dmst_portfolio_get_slug_work();
    dmst_portfolio_input('slug_work', $value);
}

/**
 * Create a dropdown page field: page services
 * @since 1.0
 */
function dmst_portfolio_field_page_services() {
    $value = dmst_portfolio_get_option('page_services', null);
    dmst_portfolio_input('page_services', $value, 'page-dropdown');
}

/**
 * Create a dropdown page field: page works
 * @since 1.0
 */
function dmst_portfolio_field_page_works() {
    $value = dmst_portfolio_get_option('page_works', null);
    dmst_portfolio_input('page_works', $value, 'page-dropdown');
}

/**
 * Create a checkbox field to configure if social share buttons are visible for services
 * @since 1.0
 */
function dmst_portfolio_field_social_services() {
    $value = dmst_portfolio_get_option('social_services', 'off');
    dmst_portfolio_input('social_services', $value, 'checkbox');
}

/**
 * Create a checkbox field to configure if social share buttons are visible for works
 * @since 1.0
 */
function dmst_portfolio_field_social_works() {
    $value = dmst_portfolio_get_option('social_works', 'off');
    dmst_portfolio_input('social_works', $value, 'checkbox');
}

/**
 * @since 1.0
 */
function dmst_portfolio_field_offer_services() {
    $value = dmst_portfolio_get_option('offer_service', __('Special offer', DMST_PORTFOLIO_TEXT_DOMAIN));
    dmst_portfolio_input('offer_service', $value);
}

/**
 * @since 1.0.1
 */
function dmst_portfolio_field_offer_detail_services() {
    $value = dmst_portfolio_get_option('offer_service_detail', __('Open special offer in another window', DMST_PORTFOLIO_TEXT_DOMAIN));
    dmst_portfolio_input('offer_service_detail', $value);
}

/**
 * Create a radio button to choose the redirection mode on services
 * @since 1.0
 */
function dmst_portfolio_field_redirect_services() {
    $value = dmst_portfolio_get_option('redirect_services', 'none');
    dmst_portfolio_input('redirect_services', 'none', 'radio', $value, __('Do not redirect', DMST_PORTFOLIO_TEXT_DOMAIN), '<ul><li>', '</li>');
    dmst_portfolio_input('redirect_services', 'redirect-service', 'radio', $value, __('Redirect to services page', DMST_PORTFOLIO_TEXT_DOMAIN), '<li>', '</li></ul>');
}

/**
 * Create a radio button to choose the redirection mode works
 * @since 1.0
 */
function dmst_portfolio_field_redirect_works() {
    $value = dmst_portfolio_get_option('redirect_works', 'none');
    dmst_portfolio_input('redirect_works', 'none', 'radio', $value, __('Do not redirect', DMST_PORTFOLIO_TEXT_DOMAIN), '<ul><li>', '</li>');
    dmst_portfolio_input('redirect_works', 'redirect-portfolio', 'radio', $value, __('Redirect to portfolio page', DMST_PORTFOLIO_TEXT_DOMAIN), '<li>', '</li>');
    dmst_portfolio_input('redirect_works', 'redirect-first-service', 'radio', $value, __('Redirect to this work first service', DMST_PORTFOLIO_TEXT_DOMAIN), '<li>', '</li></ul>');
}

/**
 * Create a radio button to choose shortcode image size for services
 * @since 1.0
 */
function dmst_portolio_field_imagesize_service() {
    $value = dmst_portfolio_get_option('imagesize_services', 'medium');
    dmst_portfolio_input('imagesize_services', 'thumbnail', 'radio', $value, __('thumbnail', DMST_PORTFOLIO_TEXT_DOMAIN), '<ul><li>', '</li>');
    dmst_portfolio_input('imagesize_services', 'medium', 'radio', $value, __('medium', DMST_PORTFOLIO_TEXT_DOMAIN), '<ul><li>', '</li>');
    dmst_portfolio_input('imagesize_services', 'large', 'radio', $value, __('large', DMST_PORTFOLIO_TEXT_DOMAIN), '<ul><li>', '</li>');
}

/**
 * Create a radio button to choose shortcode image size for works
 * @since 1.0
 */
function dmst_portolio_field_imagesize_work() {
    $value = dmst_portfolio_get_option('imagesize_works', 'medium');
    dmst_portfolio_input('imagesize_works', 'thumbnail', 'radio', $value, __('thumbnail', DMST_PORTFOLIO_TEXT_DOMAIN), '<ul><li>', '</li>');
    dmst_portfolio_input('imagesize_works', 'medium', 'radio', $value, __('medium', DMST_PORTFOLIO_TEXT_DOMAIN), '<ul><li>', '</li>');
    dmst_portfolio_input('imagesize_works', 'large', 'radio', $value, __('large', DMST_PORTFOLIO_TEXT_DOMAIN), '<ul><li>', '</li>');
}

/**
 * @since 1.0.1
 */
function dmst_portolio_field_classes_services() {
    $value = dmst_portfolio_get_option('services_classes','span6');
    dmst_portfolio_input('services_classes', $value);
}

/**
 * @since 1.0.1
 */
function dmst_portolio_field_classes_works() {
    $value = dmst_portfolio_get_option('works_classes','span6');
    dmst_portfolio_input('works_classes', $value);
}

/**
 * @since 1.0.1
 */
function dmst_portolio_field_byrow_services() {
    $value = dmst_portfolio_get_option('services_byrow','6');
    dmst_portfolio_input('services_byrow', $value);
}

/**
 * Create a checkbox field to configure if bootstrap javascript files have to be enqueued
 * @since 1.0
 */
function dmst_portfolio_field_bootstrap() {
    $value = dmst_portfolio_get_option('bootstrap', 'off');
    dmst_portfolio_input('bootstrap', $value, 'checkbox');
}

/**
 * Services section header
 * @since 1.0
 */
function dmst_portfolio_section_services() {
    echo '<p>' . __('<strong>Services</strong> are generic offers of your portfolio. Note the difference from <strong>works</strong> that are the <em>results</em> of an specific service.', DMST_PORTFOLIO_TEXT_DOMAIN) . '</p>';
    echo '<p>' . __('Configure portfolio services options', DMST_PORTFOLIO_TEXT_DOMAIN) . '</p>';
}

/**
 * Works section header
 * @since 1.0
 */
function dmst_portfolio_section_works() {
    echo '<p>' . __('Configure portfolio works options', DMST_PORTFOLIO_TEXT_DOMAIN) . '</p>';
}

/**
 * Slugs section header
 * @since 1.0
 */
function dmst_portfolio_section_slugs() {
    echo '<p>' . __('Configure portfolio slugs options', DMST_PORTFOLIO_TEXT_DOMAIN) . '</p>';
    echo '<p><strong>' . __('Attention: after changing slugs you should save Permalink options again', DMST_PORTFOLIO_TEXT_DOMAIN) . ' <a href="options-permalink.php" target="_blank">' . __('here', DMST_PORTFOLIO_TEXT_DOMAIN) . '</a></strong></p>';
}

/**
 * Advanced section header
 * @since 1.0
 */
function dmst_portfolio_section_advanced() {
    echo '<p>' . __('Configure portfolio advanced options', DMST_PORTFOLIO_TEXT_DOMAIN) . '</p>';
}

/**
 * Recursive applies esc_attr to a variable content array
 * @param array $x
 * @return array
 * @since 1.0
 */
function dmst_portfolio_esc_attr($x) {
    if (is_array($x)):
        return array_map('dmst_portfolio_esc_attr', $x);
    else:
        return esc_attr($x);
    endif;
}
?>
