<?php

/**
 * Custom Types Declaration
 * @since 1.0
 */
function dmst_portfolio_custom_types() {
    register_post_type('portfolio-service', array(
        'labels' => array(
            'name' => dmst_portfolio_get_label_services(),
            'singular_name' => dmst_portfolio_get_label_service(),
            'add_new' => __('Add', DMST_PORTFOLIO_TEXT_DOMAIN) . ' ' . dmst_portfolio_get_label_service(),
            'add_new_item' => __('Add New', DMST_PORTFOLIO_TEXT_DOMAIN) . ' ' . dmst_portfolio_get_label_service(),
            'edit' => __('Edit', DMST_PORTFOLIO_TEXT_DOMAIN),
            'edit_item' => __('Edit', DMST_PORTFOLIO_TEXT_DOMAIN) . ' ' . dmst_portfolio_get_label_service(),
            'new_item' => __('New', DMST_PORTFOLIO_TEXT_DOMAIN) . ' ' . dmst_portfolio_get_label_service(),
            'view' => __('View', DMST_PORTFOLIO_TEXT_DOMAIN),
            'view_item' => __('View', DMST_PORTFOLIO_TEXT_DOMAIN) . ' ' . dmst_portfolio_get_label_service(),
            'search_items' => __('Search', DMST_PORTFOLIO_TEXT_DOMAIN) . ' ' . dmst_portfolio_get_label_service(),
            'not_found' => __('No element found', DMST_PORTFOLIO_TEXT_DOMAIN),
            'not_found_in_trash' => __('No element found in Trash', DMST_PORTFOLIO_TEXT_DOMAIN),
            'parent' => __('Parent element', DMST_PORTFOLIO_TEXT_DOMAIN)
        ),
        'public' => true,
        'show_in_nav_menus' => true,
        'menu_position' => 15,
        'taxonomies' => array(),
        'rewrite' => array('slug' => dmst_portfolio_get_slug_service()),
        'query_var' => true,
        'has_archive' => true,
        'supports' => array(
            'title',
            'editor',
            'excerpt',
            'trackbacks',
            'custom-fields',
            'comments',
            'revisions',
            'thumbnail',
            'author',
            'page-attributes'
        )
            )
    );
    register_post_type('portfolio-work', array(
        'labels' => array(
            'name' => dmst_portfolio_get_label_works(),
            'singular_name' => dmst_portfolio_get_label_work(),
            'add_new' => __('Add', DMST_PORTFOLIO_TEXT_DOMAIN) . ' ' . dmst_portfolio_get_label_work(),
            'add_new_item' => __('Add New', DMST_PORTFOLIO_TEXT_DOMAIN) . ' ' . dmst_portfolio_get_label_work(),
            'edit' => __('Edit', DMST_PORTFOLIO_TEXT_DOMAIN),
            'edit_item' => __('Edit', DMST_PORTFOLIO_TEXT_DOMAIN) . ' ' . dmst_portfolio_get_label_work(),
            'new_item' => __('New', DMST_PORTFOLIO_TEXT_DOMAIN) . ' ' . dmst_portfolio_get_label_work(),
            'view' => __('View', DMST_PORTFOLIO_TEXT_DOMAIN),
            'view_item' => __('View', DMST_PORTFOLIO_TEXT_DOMAIN) . ' ' . dmst_portfolio_get_label_work(),
            'search_items' => __('Search', DMST_PORTFOLIO_TEXT_DOMAIN) . ' ' . dmst_portfolio_get_label_work(),
            'not_found' => __('No element found', DMST_PORTFOLIO_TEXT_DOMAIN),
            'not_found_in_trash' => __('No element found in Trash', DMST_PORTFOLIO_TEXT_DOMAIN),
            'parent' => __('Parent element', DMST_PORTFOLIO_TEXT_DOMAIN)
        ),
        'public' => true,
        'show_in_nav_menus' => true,
        'menu_position' => 15,
        'taxonomies' => array(),
        'rewrite' => array('slug' => dmst_portfolio_get_slug_work()),
        'query_var' => true,
        'has_archive' => true,
        'supports' => array(
            'title',
            'editor',
            'excerpt',
            'trackbacks',
            'custom-fields',
            'comments',
            'revisions',
            'thumbnail',
            'author',
            'page-attributes'
        )
            )
    );
    $args = register_taxonomy('portfolio-group', 'portfolio-service', array(
        'hierarchical' => false,
        'labels' => array(
            'name' => _x('Service Groups', 'taxonomy general name'),
            'singular_name' => _x('Service Group', 'taxonomy singular name'),
            'search_items' => __('Search Service Groups'),
            'popular_items' => __('Popular Service Groups'),
            'all_items' => __('All Service Groups'),
            'parent_item' => null,
            'parent_item_colon' => null,
            'edit_item' => __('Edit Service Group'),
            'update_item' => __('Update Service Group'),
            'add_new_item' => __('Add New Service Group'),
            'new_item_name' => __('New Service Group Name'),
            'separate_items_with_commas' => __('Separate service groups with commas'),
            'add_or_remove_items' => __('Add or remove service groups'),
            'choose_from_most_used' => __('Choose from the most used service groups'),
            'not_found' => __('No service groups found.'),
            'menu_name' => __('Service Groups'),
        ),
        'show_ui' => true,
        'show_admin_column' => true,
        //'update_count_callback' => '_update_post_term_count',
        'query_var' => true,
        'rewrite' => array('slug' => 'g-' . dmst_portfolio_get_slug_work()),
    ));
}

/**
 * Gets the label for work 
 * @return string
 * @since 1.0
 */
function dmst_portfolio_get_label_work() {
    return dmst_portfolio_get_option('label_work', __('Work', DMST_PORTFOLIO_TEXT_DOMAIN));
}

/**
 * Gets the label for works
 * @return string
 * @since 1.0
 */
function dmst_portfolio_get_label_works() {
    return dmst_portfolio_get_option('label_works', __('Works', DMST_PORTFOLIO_TEXT_DOMAIN));
}

/**
 * Gets the label for service
 * @return string
 * @since 1.0
 */
function dmst_portfolio_get_label_service() {
    return dmst_portfolio_get_option('label_service', __('Service', DMST_PORTFOLIO_TEXT_DOMAIN));
}

/**
 * Gets the label for services
 * @return string
 * @since 1.0
 */
function dmst_portfolio_get_label_services() {
    return dmst_portfolio_get_option('label_services', __('Services', DMST_PORTFOLIO_TEXT_DOMAIN));
}

/**
 * Gets the slug for work
 * @return string
 * @since 1.0
 */
function dmst_portfolio_get_slug_work() {
    return dmst_portfolio_get_option('slug_work', __('portfolio-work', DMST_PORTFOLIO_TEXT_DOMAIN));
}

/**
 * Gets the slug for service
 * @return string
 * @since 1.0
 */
function dmst_portfolio_get_slug_service() {
    return dmst_portfolio_get_option('slug_service', __('portfolio-service', DMST_PORTFOLIO_TEXT_DOMAIN));
}

/**
 * Writes the options field with value in the admin page
 * @param string $field the option name
 * @param string $value the option value 
 * @param string $type specifies the type of input. If not set, it will be treated as a text box. Allowed values: 'page-dropdown' to show a drop down of pages, 'radio' to show a radio button, 'checkbox' to show a checkbox
 * @param mixed $checked
 * @param string $html_before html to print before the begining of field
 * @param string $html_after html to print after the end of the field
 * @param string $label if set is showed as the radio button element label
 * @since 1.0
 */
function dmst_portfolio_input($field, $value, $type = null, $checked = false, $label = null, $html_before = '', $html_after = '') {
    echo $html_before;
    switch ($type):
        case 'page-dropdown':
            wp_dropdown_pages(array('name' => DMST_PORTFOLIO_OPTIONS . '[' . $field . ']', 'show_option_none' => __('&mdash; Select &mdash;'), 'option_none_value' => '0', 'selected' => $value));
            break;
        case 'radio':
            echo "<input id='$field' name='" . DMST_PORTFOLIO_OPTIONS . "[$field]' type='radio' value='$value'" . checked($value, $checked, false) . " />";
            if (isset($label)):
                echo " <label>$label</label>";
            endif;
            break;
        case 'checkbox':
            echo "<input id='$field' name='" . DMST_PORTFOLIO_OPTIONS . "[$field]' type='checkbox'" . checked($value, 'on', false) . " />";
            break;
        default:
            echo "<input id='" . $field . "' name='" . DMST_PORTFOLIO_OPTIONS . "[" . $field . "]' type='text' value='$value'/>";
    endswitch;
    echo $html_after;
}

/**
 * Gets a DeMomentSomTresPortfolio Option and, if not set, returns the default value provided
 * @param string $name the option name
 * @param mixed $default the default value
 * @return type the option new value
 * @since 1.0
 */
function dmst_portfolio_get_option($name, $default = null) {
    $options = get_option(DMST_PORTFOLIO_OPTIONS);
    if (!isset($options[$name])):
        return $default;
    else:
        return $options[$name];
    endif;
}

/**
 * Get the url for page services
 * @return string
 */
function dmst_portfolio_get_url_page_services() {
    $id = dmst_portfolio_get_option('page_services');
    if (!isset($id)):
        return '/./';
    else:
        return get_permalink($id);
    endif;
}

/**
 * Get the url for page works
 * @return string
 */
function dmst_portfolio_get_url_page_works() {
    $id = dmst_portfolio_get_option('page_works');
    if (!isset($id)):
        return '/./';
    else:
        return get_permalink($id);
    endif;
}

/**
 * Include redirect scripts if needed based on post-type and settings
 * @global type $post_type
 * @since 1.0
 */
function dmst_portfolio_redirect() {
    global $post_type;
    global $post;
    if ('portfolio-service' == $post_type):
        if ('redirect-service' == dmst_portfolio_get_option('redirect_services')):
            wp_enqueue_script('portfolio-redirect', DMST_PORTFOLIO_PLUGIN_URL . 'js/redirect.js', '', true);
            wp_localize_script('portfolio-redirect', 'redirect_params', array('url' => dmst_portfolio_get_url_page_services()));
        endif;
    endif;
    if ('portfolio-work' == $post_type):
        wp_enqueue_script('portfolio-redirect', DMST_PORTFOLIO_PLUGIN_URL . 'js/redirect.js', '', true);
        if ('redirect-portfolio' == dmst_portfolio_get_option('redirect_works')):
            wp_localize_script('portfolio-redirect', 'redirect_params', array('url' => dmst_portfolio_get_url_page_services()));
        endif;
        if ('redirect-first-service' == dmst_portfolio_get_option('redirect_works')):
            wp_localize_script('portfolio-redirect', 'redirect_params', array('url' => dmst_portfolio_get_url_first_service($post->ID)));
        endif;
    endif;
}

/**
 * Adds the metaboxes to the custom post types
 * @since 1.0
 */
function demomentsomtres_portfolio_add_metaboxes() {
    add_meta_box('dms3-portfolio-services', __('Services', DMST_PORTFOLIO_TEXT_DOMAIN), 'demomentsomtres_portfolio_services_metabox', 'portfolio-work', 'normal', 'high');
    add_meta_box('dms3-portfolio-offer', __('Offers', DMST_PORTFOLIO_TEXT_DOMAIN), 'demomentsomtres_portfolio_offer_metabox', 'portfolio-service', 'normal', 'high');
}

/**
 * Adds the metabox to setup services linked to a portfolio work
 * @since 1.0
 */
function demomentsomtres_portfolio_services_metabox($post) {
    $services = demomentsomtres_portfolio_services_list();
    $mainService = demomentsomtres_portfolio_mainService($post);
    $workServices = demomentsomtres_portfolio_work_services($post);
    $grey = true;
//    echo '<pre>';
//    print_r($services);
//    print_r($mainService);
//    print_r($workServices);
//    echo '</pre>';
    echo '<p>' . __("In this area you can set all services related to this work.<br/>You have to set a main service and also complimentary services.", DMST_PORTFOLIO_TEXT_DOMAIN) . '</p>';
    echo '<table width="100%" class="demomentsomtres-portfolio-services">';
    echo '<thead><tr>';
    echo '<th>' . __('Service', DMST_PORTFOLIO_TEXT_DOMAIN) . '</th>';
    echo '<th>' . __('There\'s relationship', DMST_PORTFOLIO_TEXT_DOMAIN) . '</th>';
    echo '<th>' . __('Is the main service of the work', DMST_PORTFOLIO_TEXT_DOMAIN) . '</th>';
    echo '</tr></thead>';
    echo '<tbody>';
    foreach ($services as $s => $t):
        $ck = in_array($s, $workServices);
        if ($grey):
            echo '<tr style="background-color:#ccc;">';
            $grey = false;
        else:
            echo '<tr>';
            $grey = true;
        endif;
        echo '<td>' . $t . '</td>';
        echo '<td style="text-align:center;">';
        echo '<input name="dms3-portfolio[workServices][' . $s . ']" type="checkbox" ' . checked($ck, true, false) . '/>';
        echo '</td>';
        echo '<td style="text-align:center;">';
        echo '<input name="dms3-portfolio[mainService]" value="' . $s . '" type="radio" ' . checked($s, $mainService, false) . ' />';
        echo '</td>';
        echo '</tr>';
    endforeach;
    echo '</tbody>';
    echo '</table>';
}

/**
 * Add a metabox to services in order to edit landing page and show offer information
 */
function demomentsomtres_portfolio_offer_metabox($post) {
    $show = demomentsomtres_portfolio_showOffer($post);
    $url = demomentsomtres_portfolio_landingURL($post);
    echo '<p>' . __("In this area you can set offer information on this product.", DMST_PORTFOLIO_TEXT_DOMAIN) . '</p>';
    echo '<table class="demomentsomtres-portfolio-services">';
    echo '<tr>';
    echo '<td>' . __('Show the offer', DMST_PORTFOLIO_TEXT_DOMAIN) . '</td>';
    echo '<td>' . "<input name='dms3-portfolio[showOffer]' type='checkbox' " . checked($show, true, false) . ' /></td>';
    echo '</tr>';
    echo '<tr>';
    echo '<td>' . __('Offer landing page', DMST_PORTFOLIO_TEXT_DOMAIN) . '</td>';
    echo '<td>' . "<input name='dms3-portfolio[url]' type='text' value='$url' size='75'/>" . '</td>';
    echo '</tr>';
    echo '</table>';
}

/**
 * Get the list of services
 * @return array list of all service of the form id=>name
 */
function demomentsomtres_portfolio_services_list() {
    $list = array();
    $q = new WP_Query(
            array(
        'post_type' => array('portfolio-service'),
        'showposts' => -1,
        'orderby' => 'menu_order'
            )
    );
    while ($q->have_posts()):
        $q->the_post();
        $list[$q->post->ID] = $q->post->post_title;
    endwhile;
    return $list;
}

/**
 * Get the main service of a work
 * @param mixed $post the work 
 * @return integer the main service post ID, null if no main service is set
 * @since 1.0
 */
function demomentsomtres_portfolio_mainService($post) {
    return get_post_meta($post->ID, 'demomentsomtres-portfolio-mainService', true);
}

/**
 * Get the list of services linked to a work
 * @param mixed $post the work
 * @return array the services in form of array of IDs
 */
function demomentsomtres_portfolio_work_services($post) {
    $result = get_post_meta($post->ID, 'demomentsomtres-portfolio-workServices', true);
    if (!$result):
        $result = array();
    else:
        $result = json_decode($result);
    endif;
    return $result;
}

/**
 * saves work metadata
 * @param int $post_id
 * @since 1.0
 */
function demomentsomtres_portfolio_save_work($post_id) {
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
        return $post_id;
    if (!isset($_POST['dms3-portfolio']['workServices']) OR !isset($_POST['dms3-portfolio']['mainService']))
        return $post_id;
    if ('portfolio-work' == $_POST['post_type']):
        $mainService = $_POST['dms3-portfolio']['mainService'];
        $workServices = $_POST['dms3-portfolio']['workServices'];
        $ws = array_keys($workServices);
        if ((!$mainService) && (isset($ws[0]))):
            $mainService = $ws[0];
        endif;
        if ($mainService):
            if (!isset($ws[0])):
                $ws[0] = $mainService;
            endif;
            if (!in_array($mainService, $ws)):
                $ws[] = $mainService;
            endif;
        endif;
        update_post_meta($post_id, 'demomentsomtres-portfolio-mainService', strip_tags($mainService));
        update_post_meta($post_id, 'demomentsomtres-portfolio-workServices', json_encode($ws));
        $allServices = array_keys(demomentsomtres_portfolio_services_list());
        $serviceToDelete = array_diff($allServices, $ws);
        foreach ($allServices as $s):
            if (in_array($s, $serviceToDelete)):
                delete_post_meta($post_id, 'demomentsomtres-portfolio-service-' . $s);
            else:
                update_post_meta($post_id, 'demomentsomtres-portfolio-service-' . $s, 1);
            endif;
        endforeach;
    endif;
}

/**
 * saves service metadata
 * @param int $post_id
 * @since 1.0
 */
function demomentsomtres_portfolio_save_service($post_id) {
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
        return $post_id;
//    echo '<pre>';
//    print_r($_POST);
//    echo '</pre>';
//    exit;
    if ('portfolio-service' == $_POST['post_type']):
        update_post_meta($post_id, 'demomentsomtres-portfolio-showOffer', strip_tags($_POST['dms3-portfolio']['showOffer']));
        update_post_meta($post_id, 'demomentsomtres-portfolio-landingPage', strip_tags($_POST['dms3-portfolio']['url']));
    endif;
}

/**
 * gets the url of the first service for work 
 * @param int $work_id identificator of work
 * @return string
 * @since 1.0
 */
function dmst_portfolio_get_url_first_service($work_id) {
    $service_id = get_post_meta($work_id, 'demomentsomtres-portfolio-mainService', true);
    if (!$service_id):
        return '/./';
    endif;
    return get_permalink($service_id);
}

/**
 * gets metadata to know if there's an active service offer
 * @param mixed $post
 * @return string
 * @since 1.0
 */
function demomentsomtres_portfolio_showOffer($post) {
    return ('on' == get_post_meta($post->ID, 'demomentsomtres-portfolio-showOffer', true));
}

/**
 * gets the service offer landing page url
 * @param mixed $post
 * @return string
 * @since 1.0
 */
function demomentsomtres_portfolio_landingURL($post) {
    return get_post_meta($post->ID, 'demomentsomtres-portfolio-landingPage', true);
}

/**
 * 
 * @param array $atts shortcode attributes 
 * @since 1.0
 */
function demomentsomtres_portfolio_shortcode_services($atts) {
    global $demomentsomtres_porfolio_services_script;
    $demomentsomtres_porfolio_services_script = true;
    extract(shortcode_atts(array(
        'group' => null,
        'cols' => 4,
        'workcols' => 4,
        'tag' => 'h3',
        'active' => -1
                    ), $atts));
    $html = '';
    $ServicesClasses = dmst_portfolio_get_option('services_classes', '');
    $ServicesClasses = ($ServicesClasses == '') ? $ServicesClasses : ' ' . $ServicesClasses;
    $WorksClasses = dmst_portfolio_get_option('works_classes', '');
    $WorksClasses = ($WorksClasses == '') ? $WorksClasses : ' ' . $WorksClasses;
    $services = demomentsomtres_portfolio_services($group);
    $html .= '<div class="demomentsomtres-portfolio-services">';
    //$byrow = (int) (12 / $cols);
    //$span = (int) (12/$byrow);
    $byrow = $cols;
    $span = (int) (12 / $byrow);
    $i = 0;
    $r = 0;
    foreach ($services as $s):
        $activeClass = ($s->ID == $active) ? ' active' : '';
        if (0 == $i % $byrow):
            // in a new row
            $html .= "<div class='tabbable dms3-portfolio-row$r'>";
            $html .= "<ul class='nav nav-tabs row-fluid thumbnails'>";
            $tabcontent = "<div class='tab-content'>";
        endif;
        $html .= "<li class='span$span$activeClass'><a href='#$s->post_name' data-toggle='tab'>";
        $html .= demomentsomtres_portfolio_html_featuredImage_service($s);
        $html .= "<span class='portfolio-title'><span class='service-title'>$s->post_title</span>";
        $html .= demomentsomtres_portfolio_html_specialOffer($s);
        $html .= "</span></a></li>";
        $tabcontent.="<div class='tab-pane$activeClass' id='$s->post_name'>"
                . demomentsomtres_portfolio_html_specialOffer($s, true)
                . "<div class='row-fluid'>"
                . "<div class='content$ServicesClasses'>"
                . "<$tag>" . $s->post_title . "</$tag>"
                . $s->post_content
                . "</div><!--content--><div class='gallery$WorksClasses'>"
                . demomentsomtres_portfolio_shortcode_works(array(
                    'service' => $s->ID,
                    'cols' => $workcols
                ))
                . "</div><!--gallery-->"
                . "<a href='#' class='close'>" . __('Close', DMST_PORTFOLIO_TEXT_DOMAIN) . '</a>'
                . "</div><!--row fluid--></div><!--tab pane-->";
        if ($byrow - 1 == $i % $byrow):
            // end of row
            $html .= '</ul>';
            $html .= $tabcontent;
            $html .= "</div><!--tabcontent-->";
            $html .= "</div><!--protfolio-row-->";
        endif;
        $i++;
        $r = $r % 2;
    endforeach;
    if (0 != ($i) % $byrow):
        // was not ended
        $html .= '</ul>';
        $html .= $tabcontent;
        $html .= "</div><!--tabcontent-->";
        $html .= "</div><!--protfolio-row-->";
    endif;
    $html .= '</div><!--demomentsomtres-portfolio-->';
    //echo '<pre style="display:none;">';print_r($services);echo '</pre>';
    return $html;
}

/**
 * 
 * @param array $atts shortcode attributes 
 * @since 1.0
 */
function demomentsomtres_portfolio_shortcode_works($atts) {
    global $demomentsomtres_porfolio_works_script;
    $demomentsomtres_porfolio_works_script = true;
    extract(shortcode_atts(array(
        'service' => null,
        'cols' => 4,
        'samepage'=>0,
                    ), $atts));
    $html = '';
    //$html = '<pre style="display:none;">'.print_r($atts,true).'</pre>';
    $works = demomentsomtres_portfolio_works($service);
    $html .= '<div class="demomentsomtres-portfolio-works">';
    //$byrow = (int) (12 / $cols);
    //$span = (int) (12/$byrow);
    $byrow = $cols;
    $span = (int) (12 / $byrow);
    $i = 0;
    $r = 0;
    if ($samepage==0):
        $target="target='_blank'";
    else:
        $target='';
    endif;
    foreach ($works as $w):
        if (0 == $i % $byrow):
            // in a new row
            $html .= "<ul class = 'dms3-portfolio-row$r row-fluid thumbnails'>";
        endif;
        $url = get_permalink($w->ID);
        $html .= "<li class = 'span$span thumbnail'>";
        $html .= "<a href = '$url' $target title = '$w->post_title'>";
        $html .= demomentsomtres_portfolio_html_featuredImage_work($w);
        $html .= "<div class = 'caption portfolio-title'>$w->post_title</div>";
        $html .= '</a>';
        $html .= "</li>";
        if ($byrow - 1 == $i % $byrow):
            // end of row
            $html .= '</ul>';
        endif;
        $i++;
        $r = $r % 2;
    endforeach;
    if (0 != ($i) % $byrow):
        // was not ended
        $html .= '</ul>';
    endif;
    $html .= '</div><!--demomentsomtres-portfolio-->';
    return $html;
}

/**
 * generate the special offer html for the given service
 * @param mixed $service the service post
 * @param boolean $link shows the landing page link
 * @return string the html
 */
function demomentsomtres_portfolio_html_specialOffer($service, $link = false) {
    $text = dmst_portfolio_get_option('offer_service', __('Special offer', DMST_PORTFOLIO_TEXT_DOMAIN));
    $textDetail = dmst_portfolio_get_option('offer_service_detail', __('Open special offer in another window', DMST_PORTFOLIO_TEXT_DOMAIN));
    $show = demomentsomtres_portfolio_showOffer($service);
    $url = demomentsomtres_portfolio_landingURL($service);
    $html = '';
    if ($show):
        if ($link):
            $html.="<a class = 'specialOffer label' href = '$url' target = '_blank'>";
            $html .= $textDetail;
            $html.="</a>";
        else:
            $html.=" <span class = 'specialOffer label'>";
            $html.=$text;
            $html.="</span>";
        endif;
    endif;
    return $html;
}

/**
 * generate the featured image for the given service
 * @param type $service the service post
 * @return string the html
 */
function demomentsomtres_portfolio_html_featuredImage_service($service) {
    $html = '<div class="passepartout">';
    $size = dmst_portfolio_get_option('imagesize_services', 'medium');
    if (has_post_thumbnail($service->ID)):
        $html.=get_the_post_thumbnail($service->ID, $size, array(
            'class' => 'service-thumb',
            'alt' => dmst_portfolio_get_label_service() . ' ' . $service->post_title,
        ));
    else:
        $html.="<img class = 'service-thumb service-thumb-empty' src = '' />";
    endif;
    $html.='</div>';
    return $html;
}

/**
 * generate the featured image for the given work
 * @param type $service the service post
 * @return string the html
 */
function demomentsomtres_portfolio_html_featuredImage_work($work) {
    $html = '<div class="passepartout">';
    $size = dmst_portfolio_get_option('imagesize_works', 'medium');
    if (has_post_thumbnail($work->ID)):
        $html.=get_the_post_thumbnail($work->ID, $size, array(
            'class' => 'work-thumb',
            'alt' => dmst_portfolio_get_label_work() . ' ' . $work->post_title,
        ));
    else:
        $html.="<img class = 'work-thumb service-work-empty' src = '' />";
    endif;
    $html.='</div>';
    return $html;
}

/**
 * Get all portfolio services posts
 * @param string $group the slug of the portfolio service
 * @return array the posts of services
 * @since 1.0
 */
function demomentsomtres_portfolio_services($group = null) {
    if ($group):
        $q = new WP_Query(
                array(
            'post_type' => array('portfolio-service'),
            'portfolio-group' => $group,
            'showposts' => -1,
            'order' => 'ASC',
            'orderby' => 'menu_order'
                )
        );
    else:
        $q = new WP_Query(
                array(
            'post_type' => array('portfolio-service'),
            'showposts' => -1,
            'order' => 'ASC',
            'orderby' => 'menu_order'
                )
        );
    endif;
    return $q->posts;
}

/**
 * Get all portfolio works posts
 * @param $serviceID the service id
 * @return array the posts of works
 * @since 1.0
 */
function demomentsomtres_portfolio_works($serviceID = null) {
    if ($serviceID):
        $q = new WP_Query(
                array(
            'post_type' => array('portfolio-work'),
            'meta_key' => 'demomentsomtres-portfolio-service-' . $serviceID,
//            'meta_value' => 1,
            'showposts' => -1,
            'orderby' => 'menu_order'
                )
        );
//    echo '<pre>' . print_r($q, true) . '</pre>';
    else:
        $q = new WP_Query(
                array(
            'post_type' => array('portfolio-work'),
            'showposts' => -1,
            'orderby' => 'menu_order'
                )
        );
    endif;
    return $q->posts;
}

/**
 * Register the scripts required by shortcodes in this plugin
 * @since 1.0
 */
function dmst_portfolio_register_shortcode_scripts() {
    wp_register_script('portfolio-services', DMST_PORTFOLIO_PLUGIN_URL . 'js/services.js', 'jquery', true);
//    wp_register_script('portfolio-works', DMST_PORTFOLIO_PLUGIN_URL . 'js/works.js', 'jquery', true);
}

/**
 * Print the scripts on footer if required by shortcodes
 * @since 1.0
 */
function dmst_portfolio_print_scripts() {
    global $demomentsomtres_porfolio_services_script;
    global $demomentsomtres_porfolio_works_script;
    if (($demomentsomtres_porfolio_services_script) || ($demomentsomtres_porfolio_works_script))
        wp_print_scripts('jquery');
    if ($demomentsomtres_porfolio_services_script)
        wp_print_scripts('portfolio-services');
//    if ($demomentsomtres_porfolio_works_script)
//        wp_print_scripts('portfolio-works');
}

/**
 * @since 1.0.1
 * @global type $current_screen
 * @return type
 */
function demomentsomtres_portfolio_insert_buttons() {
    global $current_screen;
    if ((!current_user_can('edit_posts') && !current_user_can('edit_pages') ) && get_user_option('rich_editing')):
        return;
    endif;
    if (get_user_option('rich_editing')):
        add_filter('mce_buttons', 'demomentsomtres_portfolio_register_buttons');
        add_filter("mce_external_plugins", "demomentsomtres_portfolio_add_tinymce_plugin");
    endif;
}

/**
 * Registers buttons to TinyMCE
 * @param array $buttons
 * @return array
 * @since 1.0.1
 */
function demomentsomtres_portfolio_register_buttons($buttons) {
    array_push($buttons, "dms3PortfolioServices", "dms3PortfolioWorks");
    return $buttons;
}

/**
 * Adds Load the TinyMCE plugin : editor_plugin.js
 * @param array $plugin_array
 * @return type
 * @since 1.0.1
 */
function demomentsomtres_portfolio_add_tinymce_plugin($plugin_array) {
    $plugin_array['dms3Portfolio'] = plugins_url('mce_plugins/editor_plugin.js', __FILE__);
    return $plugin_array;
}

/**
 * @since 1.0.2
 */
function dmst_portfolio_plugin_init() {
    load_plugin_textdomain(DMST_PORTFOLIO_TEXT_DOMAIN, false, DMST_PORTFOLIO_LANG_DIR);
}

?>
